@@ -14,7 +14,7 @@ import pathlib
 
 
 class App:
-    def __init__(self, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000):
+    def __init__(self, templates_dir="templates", static_dir="static", exception_handler=None, host="127.0.0.1", port=5000, default_middleware=True):
         self.routes = {}
         self.host = host
         self.port = port
@@ -36,7 +36,10 @@ class App:
 
         self.middleware = Middleware(self)
 
-        self.add_middleware(DefaultMiddleware)
+        if default_middleware:
+            self.add_middleware(DefaultMiddleware)
+
+        self.collections = []
 
         self.server = Server(
             bind_addr=(self.host, self.port),
@@ -147,6 +150,16 @@ class App:
     def get_cookie(self, key, req):
         return dict(req.cookies)[key]
 
+    def register_collection(self, collection):
+        assert collection not in self.collections, f"Collection {collection} already registered"
+        for path in collection.routes.keys():
+            assert path not in self.routes, f"Route {path} already exists"
+
+            self.routes[path] = collection.routes[path]
+
+        self.routes.update(collection.routes)
+        self.collections.append(collection)
+
     def run(self):
         try:
             print(f"[INFO] Running on http://{self.host}:{self.port}")
